@@ -115,6 +115,22 @@ class Etcd3Driver(coordination.CoordinationDriverCachedRunWatchers,
 
     This driver uses etcd provide the coordination driver semantics and
     required API(s).
+
+    The Etcd driver connection URI should look like::
+
+      etcd3://[HOST[:PORT]][?OPTION1=VALUE1[&OPTION2=VALUE2[&...]]]
+
+    If not specified, HOST defaults to localhost and PORT defaults to 2379.
+    Available options are:
+
+    ==================  =======
+    Name                Default
+    ==================  =======
+    protocol            http
+    timeout             30
+    lock_timeout        30
+    membership_timeout  30
+    ==================  =======
     """
 
     #: Default socket/lock/member/leader timeout used when none is provided.
@@ -160,10 +176,10 @@ class Etcd3Driver(coordination.CoordinationDriverCachedRunWatchers,
     GROUP_PREFIX = b"tooz/groups/"
 
     def _encode_group_id(self, group_id):
-        return self.GROUP_PREFIX + group_id + b"/"
+        return self.GROUP_PREFIX + utils.to_binary(group_id) + b"/"
 
     def _encode_group_member_id(self, group_id, member_id):
-        return self._encode_group_id(group_id) + member_id
+        return self._encode_group_id(group_id) + utils.to_binary(member_id)
 
     def create_group(self, group_id):
         encoded_group = self._encode_group_id(group_id)
