@@ -18,9 +18,7 @@ import hashlib
 import struct
 import time
 
-from concurrent import futures
 import msgpack
-from oslo_utils import encodeutils
 import six
 import sysv_ipc
 
@@ -73,7 +71,10 @@ class IPCLock(locking.Lock):
         else:
             return True
 
-    def acquire(self, blocking=True):
+    def acquire(self, blocking=True, shared=False):
+        if shared:
+            raise tooz.NotImplemented
+
         if (blocking is not True and
                 sysv_ipc.SEMAPHORE_TIMEOUT_SUPPORTED is False):
             raise tooz.NotImplemented("This system does not support"
@@ -133,13 +134,17 @@ class IPCLock(locking.Lock):
         return False
 
 
-class IPCDriver(coordination.CoordinationDriver):
+class IPCDriver(coordination.CoordinationDriverWithExecutor):
     """A `IPC`_ based driver.
 
     This driver uses `IPC`_ concepts to provide the coordination driver
     semantics and required API(s). It **is** missing some functionality but
     in the future these not implemented API(s) will be filled in.
 
+    The IPC driver connection URI should look like::
+
+      ipc://
+
     General recommendations/usage considerations:
 
     - It is **not** distributed (or recommended to be used in those
@@ -164,21 +169,16 @@ class IPCDriver(coordination.CoordinationDriver):
     _GROUP_PROJECT = "_TOOZ_INTERNAL"
     _INTERNAL_LOCK_NAME = "TOOZ_INTERNAL_LOCK"
 
-    def __init__(self, member_id, parsed_url, options):
-        """Initialize the IPC driver."""
-        super(IPCDriver, self).__init__(member_id)
-        self._executor = utils.ProxyExecutor.build("IPC", options)
-
     def _start(self):
+        super(IPCDriver, self)._start()
         self._group_list = sysv_ipc.SharedMemory(
             ftok(self._GROUP_LIST_KEY, self._GROUP_PROJECT),
             sysv_ipc.IPC_CREAT,
             size=self._SEGMENT_SIZE)
         self._lock = self.get_lock(self._INTERNAL_LOCK_NAME)
-        self._executor.start()
 
     def _stop(self):
-        self._executor.stop()
+        super(IPCDriver, self)._stop()
         try:
             self._group_list.detach()
             self._group_list.remove()
@@ -209,7 +209,8 @@ class IPCDriver(coordination.CoordinationDriver):
                 group_list.add(group_id)
                 self._write_group_list(group_list)
 
-        return IPCFutureResult(self._executor.submit(_create_group))
+        return coordination.CoordinatorResult(
+            self._executor.submit(_create_group))
 
     def delete_group(self, group_id):
         def _delete_group():
@@ -220,7 +221,8 @@ class IPCDriver(coordination.CoordinationDriver):
                 group_list.remove(group_id)
                 self._write_group_list(group_list)
 
-        return IPCFutureResult(self._executor.submit(_delete_group))
+        return coordination.CoordinatorResult(
+            self._executor.submit(_delete_group))
 
     def watch_join_group(self, group_id, callback):
         # Check the group exist
@@ -237,26 +239,9 @@ class IPCDriver(coordination.CoordinationDriver):
             return self._read_group_list()
 
     def get_groups(self):
-        return IPCFutureResult(self._executor.submit(
+        return coordination.CoordinatorResult(self._executor.submit(
             self._get_groups_handler))
 
     @staticmethod
     def get_lock(name):
         return IPCLock(name)
-
-
-class IPCFutureResult(coordination.CoordAsyncResult):
-    """IPC asynchronous result that references a future."""
-    def __init__(self, fut):
-        self._fut = fut
-
-    def get(self, timeout=10):
-        try:
-            return self._fut.result(timeout=timeout)
-        except futures.TimeoutError as e:
-            utils.raise_with_cause(coordination.OperationTimedOut,
-                                   encodeutils.exception_to_unicode(e),
-                                   cause=e)
-
-    def done(self):
-        return self._fut.done()
