@@ -190,6 +190,23 @@ class MemcachedDriver(coordination.CoordinationDriverCachedRunWatchers,
     all of the coordination driver API(s). It stores data into memcache
     using expiries and `msgpack`_ encoded values.
 
+    The Memcached driver connection URI should look like::
+
+      memcached://[HOST[:PORT]][?OPTION1=VALUE1[&OPTION2=VALUE2[&...]]]
+
+    If not specified, HOST defaults to localhost and PORT defaults to 11211.
+    Available options are:
+
+    ==================  =======
+    Name                Default
+    ==================  =======
+    timeout             30
+    membership_timeout  30
+    lock_timeout        30
+    leader_timeout      30
+    max_pool_size       None
+    ==================  =======
+
     General recommendations/usage considerations:
 
     - Memcache (without different backend technology) is a **cache** enough
@@ -285,13 +302,13 @@ class MemcachedDriver(coordination.CoordinationDriverCachedRunWatchers,
         self.client.close()
 
     def _encode_group_id(self, group_id):
-        return self.GROUP_PREFIX + group_id
+        return self.GROUP_PREFIX + utils.to_binary(group_id)
 
     def _encode_member_id(self, member_id):
-        return self.MEMBER_PREFIX + member_id
+        return self.MEMBER_PREFIX + utils.to_binary(member_id)
 
     def _encode_group_leader(self, group_id):
-        return self.GROUP_LEADER_PREFIX + group_id
+        return self.GROUP_LEADER_PREFIX + utils.to_binary(group_id)
 
     @_retry.retry()
     def _add_group_to_group_list(self, group_id):
